@@ -5,7 +5,7 @@ from hydenv.backend import run as backend_run
 
 from hydenv.scripts.hobo_import import HydenvHoboImporterCli
 from hydenv.examples.examples import HydenvExamples
-
+from hydenv.gui.start import run as run_gui
 
 import fire
 fire.Fire({
@@ -15,6 +15,8 @@ fire.Fire({
     'exercise': HydenvExercises,
     'backend': backend_run,
     'hobo': HydenvHoboImporterCli,
+    'gui': run_gui,
+    'GUI': run_gui,
     'example': HydenvExamples,
     'examples': HydenvExamples
 })
